#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define octpkg  parallel
Name:           octave-forge-%{octpkg}
Version:        4.0.1
Release:        bp156.4.6
Summary:        Parallel Computing for Octave
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://octave.sourceforge.io/%{octpkg}/index.html
Source0:        https://downloads.sourceforge.net/octave/%{octpkg}-%{version}.tar.gz
Patch0:         0001-Bug62349-fix-missing-num_processors.patch
# PATCH-FIX-UPSTREAM parallel-missing-header-cdef_object.patch https://savannah.gnu.org/bugs/?63922 badshah400@gmail.com -- Fix no member named 'cdef_object' in namespace 'octave'
Patch1:         parallel-missing-header-cdef_object.patch
BuildRequires:  gcc-c++
BuildRequires:  gnutls-devel >= 3.4.0
BuildRequires:  hdf5-devel
BuildRequires:  octave-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
Requires:       octave-cli >= 4.0.0
Requires:       octave-forge-struct >= 1.0.12

%description
Parallel execution package.
This is part of Octave-Forge project.

%prep
%setup -q -c %{name}-%{version}
%patch0
%patch1 -p1
%octave_pkg_src

%build
%octave_pkg_build

%install
%octave_pkg_install

%check
%octave_pkg_test

%post
%octave --eval "pkg rebuild"

%postun
%octave --eval "pkg rebuild"

%files
%{octpackages_dir}/%{octpkg}-%{version}
%{octlib_dir}/%{octpkg}-%{version}

%changelog
* Tue Apr 18 2023 Atri Bhattacharya <badshah400@gmail.com>
- Add parallel-missing-header-cdef_object.patch Fix no member
  named 'cdef_object' in namespace 'octave'
  (https://savannah.gnu.org/bugs/?63922).
* Fri Feb 10 2023 Markus Ebner <info@ebner-markus.de>
- Add patch 0001-Bug62349-fix-missing-num_processors.patch
  Fixes loading the package in newer Octave versions
  From: https://savannah.gnu.org/bugs/?62349
* Mon Mar 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 4.0.1:
  * The current search path is now set in the Octave sessions used
    by parcellfun and pararrayfun.
  * In starting parallel Octave sessions by parcellfun,
    pararrayfun, or the remote server, the executable
    'octave-cli-<current_version>' is prefered over 'octave-cli'.
  * Fixed bug that produced an error for not enough output
    arguments.
  * Fixed handling of execution errors by parcellfun and
    pararrayfun.
  * The documentation now mentions the limitation that
    command-line functions can't be used by parcellfun or
    pararrayfun.
* Thu May  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.0.0:
  * New systems both for local and cluster-based parallel execution:
    Octave sessions directly generated by 'fork()' are not used
    anymore for parallel execution. Instead, freshly started Octave
    sessions are used. This fixes problems with threads of Octave and
    of libraries used by Octave. For parcellfun/pararrayfun, it
    introduces some limitations, in particular with anonymous
    functions in Octave versions < 5.1.
  * The package should now run on Windows, too, though this is less
    tested than running on GNU/Linux.
  * The server for cluster-based execution is not installed on Windows
    or macOS (the client and the system for local parallel execution
    are).
  * Compatible with Octave 5.2 and current (2020-04-11) development
    version of Octave.
  * Removed deprecated function scloseall().
- Drop obsolete octave-forge-parallel-build-with-octave5.patch
* Sat Mar  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Spec file cleanup, remove %%defattr, correct bugzilla link
- Require gnutls >= 3.4.0
- Update URL: and Source: to use https://
* Sat Mar  9 2019 Atri B <badshah400@gmail.com>
- Add octave-forge-parallel-build-with-octave5.patch to fix
  building against octave >= 5; patch taken from upstream
  mercurial repo commits. Add automake and autoconf to
  BuildRequires since patch touches build files.
* Thu Aug 16 2018 badshah400@gmail.com
- Update to version 3.1.3:
  * Fixed building with newer gnutls versions.
  * Fixed building with Octave 4.0.
  * Change formal dependency on Octave to versions >= 4.0.
* Wed Jun  6 2018 badshah400@gmail.com
- Update to version 3.1.2:
  * Octave 4.4 compatibility.
* Mon Oct 31 2016 dmitry_r@opensuse.org
- Update to version 3.1.1
  * Compatibility with Octave 4.2.
  * Links to core Octave documentation work now in html version of
    package documentation.
* Fri Jun 10 2016 dmitry_r@opensuse.org
- Update to version 3.1.0
  * Added general package documentation, accessible with function
    'parallel_doc'.
  * Fixed handling of argument and output dimensions in netcellfun and
    netarrayfun.
  * In connecting a cluster, package version and connection protocol
    are checked. Will work only with packages from this version
    upwards.
  * Variables are transferred more efficiently.
  * If cluster functions are to be disabled at configure time, this
    has to be done always explicitely now.
* Fri Oct 30 2015 dmitry_r@opensuse.org
- Update to version 3.0.3
  * Bugfix release
* Thu Aug 13 2015 dmitry_r@opensuse.org
- Update to version 3.0.2
  * Bugfix release
* Tue Jul 14 2015 dmitry_r@opensuse.org
- Update to version 3.0.0
  * 'parcellfun' and 'pararrayfun' accept an option "CumFunc" for
    cumulative results.
  * Fix handling of option "UniformOutput" with option "Vectorized" in
    'pararrayfun'.
  * Function 'connect()' has been renamed to 'pconnect()' since the
    previous name is used by the control package.
  * New functions 'netcellfun' and 'netarrayfun' for remote parallel
    execution.
  * New convenience function 'rfeval' for single remote function
    execution.
  * New function 'install_vars' to distribute named variables over the
    parallel cluster.
  * The value returned by pconnect and the variable 'sockets' held by
    pserver, holding the network connections, are now opaque. Indexing
    the connections in this value should work as with the matrix used
    before.
  * Connections can be based on TLS-SRP, which is now the default. New
    function parallel_generate_srp_data generates authorization data.
  * Parallel cluster commands hanging in system calls (e.g. trying to
    read data that was not sent) can be interrupted with Ctrl-C
    (invalidating the network connections in most cases, so that
    information within server memory will be lost).
  * New functions 'network_get_info' and 'network_set'.
  * Within a particular parallel network, servers are supposed to be
    unique now. But a server can be a part of several parallel
    networks, and successful connection attempts of such overlapping
    networks should now be possible even if initiated from different
    client machines or client processes at the same time.
  * Removed deprecated bw_... group of functions.
* Fri Mar 13 2015 dmitry_r@opensuse.org
- Updte to version 2.2.1
  * The bw_... group of functions has been deprecated and will be
    removed in the future.
  * Made compatible with Octave 4.0.
  * Made parcellfun/pararrayfun a bit more stable.
* Thu Feb 26 2015 dmitry_r@opensuse.org
- Split from octave-forge package, version 2.2.0
